/*! edgebabel v0.1.0 by Sebastian Software <s.werner@sebastian-software.de> */
'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var envPreset = _interopDefault(require('babel-preset-env'));
var reactPreset = _interopDefault(require('babel-preset-react'));
var flowPreset = _interopDefault(require('babel-preset-flow'));
var dynamicImportPlugin = _interopDefault(require('babel-plugin-syntax-dynamic-import'));
var moduleResolverPlugin = _interopDefault(require('babel-plugin-module-resolver'));
var fastAsyncPlugin = _interopDefault(require('babel-plugin-fast-async'));
var classPropertiesPlugin = _interopDefault(require('babel-plugin-transform-class-properties'));
var objectRestSpreadPlugin = _interopDefault(require('babel-plugin-transform-object-rest-spread'));

/* eslint-disable filenames/match-exported */
function buildPreset() {
  var opts = 1 < arguments.length && arguments[1] !== undefined ? arguments[1] : {},
      presets = [],
      plugins = [];


  presets.push([envPreset, {
    // Setting this to false will not transform modules.
    // "modules": false,
    useBuiltIns: true,
    exclude: ["transform-regenerator"],
    targets: {
      browsers: ["last 2 versions"],
      node: "current"
    }
  }]);

  presets.push(reactPreset);
  presets.push(flowPreset);

  // Support for new @import() syntax
  plugins.push(dynamicImportPlugin);

  // Supports loading files in source folder without relative folders
  plugins.push([moduleResolverPlugin, {
    root: ["src"]
  }]);

  // Alternative to Babel Regenerator
  // Implements the ES7 keywords async and await using syntax transformation at compile-time, rather than generators.
  plugins.push(fastAsyncPlugin);

  // Support for ES7 Class Properties (currently stage-2)
  plugins.push(classPropertiesPlugin);

  // Support for Object Rest Spread `...` operator in objects.
  plugins.push([objectRestSpreadPlugin, { useBuiltIns: true }]);

  // Assemble final config
  return {
    presets: presets,
    plugins: plugins
  };
}

module.exports = buildPreset;
//# sourceMappingURL=node.commonjs.js.map
